package org.serviio.ui.restlet;

import org.restlet.Request;
import org.restlet.Response;
import org.restlet.data.MediaType;
import org.restlet.data.Status;
import org.restlet.ext.gson.GsonRepresentation;
import org.restlet.representation.Representation;
import org.restlet.resource.ResourceException;
import org.restlet.service.StatusService;
import org.serviio.ui.representation.ResultRepresentation;
import org.serviio.ui.resources.ValidationException;

public class ServiioStatusService extends StatusService {
	public Representation getRepresentation(Status status, Request request,
			Response response) {
		if ((status.getThrowable() != null)
				&& (status.getThrowable() instanceof ValidationException)) {
			response.setStatus(Status.SUCCESS_OK);
			int errorCode = ((ValidationException) status.getThrowable())
					.getErrorCode();
			// OFU
			ResultRepresentation r = responseError(errorCode, status.getCode());
			// find mediatype
			MediaType mt = request.getEntity().getMediaType();
			// if json
			if( MediaType.APPLICATION_JSON.equals(mt) )
				return new GsonRepresentation<ResultRepresentation>(r);
			else
				return new ServiioXstreamRepresentation<ResultRepresentation>(
						mt, r);
		}
		return null;
	}

	public Status getStatus(Throwable throwable, Request request,
			Response response) {
		Status result = null;

		if (throwable instanceof ResourceException) {
			ResourceException re = (ResourceException) throwable;
			result = re.getStatus();
		} else if (throwable instanceof ValidationException) {
			result = new Status(Status.CLIENT_ERROR_BAD_REQUEST, throwable);
		} else {
			result = new Status(Status.SERVER_ERROR_INTERNAL, throwable);
		}

		return result;
	}

	private ResultRepresentation responseError(int errorCode, int httpCode) {
		return new ResultRepresentation(errorCode, httpCode);
	}
}
